Class: Rack::Cache::EntityStore
Overview
Rack::Cache will look for a constant matching the uri scheme given to the :metastore and :entitystore options when initialising the Middleware
Constant Summary collapse
- RADIANT =
Radiant::Cache::EntityStore
Rack::Cache will look for a constant matching the uri scheme given to the :metastore and :entitystore options when initialising the Middleware
Radiant::Cache::EntityStore