Method: Radiant::ExtensionPath#load_paths
- Defined in:
- lib/radiant/extension_path.rb
#load_paths ⇒ Object
Returns a list of all the likely load paths found within this extension root. It includes all of these that exist and are directories:
-
path
-
path/lib
-
path/app/models
-
path/app/controllers
-
path/app/metal
-
path/app/helpers
-
path/test/helpers
You can call the class method ExtensionPath.load_paths to get a flattened list of all the load paths in all the enabled extensions.
72 73 74 |
# File 'lib/radiant/extension_path.rb', line 72 def load_paths %w(lib app/models app/controllers app/metal app/helpers test/helpers).collect { |d| check_subdirectory(d) }.push(path).flatten.compact end |